@@ -54,7 +54,6 @@ OC.L10N.register(
     "Favorite files" : "Obľúbené súbory",
     "No favorites" : "Žiadne obľúbené",
     "More favorites" : "Viac obľúbených",
-    "Upload (max. %s)" : "Nahrať (max. %s)",
     "Accept" : "Prijať",
     "Reject" : "Odmietnuť",
     "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
@@ -69,10 +68,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
     "in %s" : "v %s",
     "Transferred from %1$s on %2$s" : "Prevedené z %1$s na %2$s",
-    "Files compatibility" : "Kompatibilita súborov",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Povoliť obmedzenie názvov súborov, aby sa zabezpečila synchronizácia súborov so všetkými klientmi. V predvolenom nastavení sú povolené všetky názvy súborov platné pre POSIX (napr. Linux alebo macOS).",
-    "Enforce Windows compatibility" : "Vynútiť kompatibilitu s Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tým sa zablokujú názvy súborov, ktoré nie sú platné v systémoch Windows, ako napríklad používanie vyhradených názvov alebo špeciálnych znakov. To však nevynúti kompatibilitu rozlišovania malých a veľkých písmen.",
     "File Management" : "Správa súborov",
     "Home" : "Domov",
     "Target folder does not exist any more" : "Cieľový priečinok už neexistuje",
@@ -100,6 +95,7 @@ OC.L10N.register(
     "Unknown date" : "Neznámy dátum",
     "Clear filter" : "Vyčistiť filter",
     "Modified" : "Upravené",
+    "Search everywhere" : "Hľadať všade",
     "Type" : "Typ",
     "Active filters" : "Aktívne filtre",
     "Remove filter" : "Odstrániť filter",
@@ -107,9 +103,6 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Prepnúť výber pre všetky súbory a adresáre",
     "Name" : "Názov",
     "Size" : "Veľkosť",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
-    "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
-    "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
     "Actions" : "Akcie",
     "(selected)" : "(vybrané)",
     "List of files and folders." : "Zoznam súborov a priečinkov.",
@@ -117,7 +110,7 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Stĺpce hlavičiek s tlačidlami sú triediteľné.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
     "File not found" : "Súbor nenájdený",
-    "{count} selected" : "{count} vybraných",
+    "_{count} selected_::_{count} selected_" : ["{count} vybraný","{count} vybrané","{count} vybraných","{count} vybraných"],
     "{usedQuotaByte} used" : "{usedQuotaByte} použitých",
     "{used} of {quota} used" : "použitých {used} z {quota}",
     "{relative}% used" : "{relative}% použitých",
@@ -129,6 +122,8 @@ OC.L10N.register(
     "Create new folder" : "Vytvoriť nový priečinok",
     "This name is already in use." : "Toto meno je už používané.",
     "Create" : "Vytvoriť",
+    "Refresh" : "Obnoviť",
+    "Limit" : "Limit",
     "Fill template fields" : "Vyplňte položky šablóny",
     "Submitting fields …" : "Položky sa odosielajú ...",
     "Submit" : "Odoslať",
@@ -166,13 +161,11 @@ OC.L10N.register(
     "Error during upload: {message}" : "Chyba počas nahrávania: {message}",
     "Error during upload, status code {status}" : "Chyba počas nahrávania, chybový kód {status}",
     "Unknown error during upload" : "Neznáma chyba počas nahrávania",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" akcia vykonaná úspešne",
     "Loading current folder" : "Načítavanie súčasného priečinka",
     "Retry" : "Zopakovať",
     "No files in here" : "Nie sú tu žiadne súbory",
     "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
     "Go back" : "Ísť späť",
-    "Filter file names …" : "Filtrovať názvy súborov ...",
     "Views" : "Zobrazenia",
     "Files settings" : "Nastavenia súborov",
     "Your files" : "Vaše súbory",
@@ -180,46 +173,38 @@ OC.L10N.register(
     "File cannot be accessed" : "Súbor nie je možné sprístupniť",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Súbor sa nenašiel alebo nemáte oprávnenie na jeho zobrazenie. Požiadajte odosielateľa, aby ho sprístupnil.",
     "Clipboard is not available" : "Schránka nie je prístupná",
-    "WebDAV URL copied to clipboard" : "WebDAV URL skopirovaná do schránky",
+    "General" : "Všeobecné",
+    "All files" : "Všetky súbory",
+    "Personal files" : "Osobné súbory",
     "Sort favorites first" : "Zoradiť od najobľúbenejších",
     "Sort folders before files" : "Zoradiť adresáre pred súbormi",
+    "Appearance" : "Vzhľad",
     "Show hidden files" : "Zobraziť skryté súbory",
     "Crop image previews" : "Orezať náhľady obrázkov",
-    "Enable the grid view" : "Povoliť zobrazenie v mriežke",
-    "Enable folder tree" : "Povoliť adresárový strom",
     "Additional settings" : "Ďalšie nastavenia",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Skopírovať do schránky",
-    "Use this address to access your Files via WebDAV" : "Táto adresa sa používa na prístup k vašim súborom prostredníctvom WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ak ste povolili 2FA, musíte kliknutím sem vytvoriť a použiť nové heslo pre aplikáciu.",
+    "Copy" : "Kopírovať",
     "Warnings" : "Upozornenia",
-    "Prevent warning dialogs from open or reenable them." : "Zabrániť otváraniu varovných dialógov alebo ich znova povoliť.",
-    "Show a warning dialog when changing a file extension." : "Pri zmene prípony súboru zobraziť dialógové okno s upozornením.",
     "Keyboard shortcuts" : "Klávesové skratky",
-    "Speed up your Files experience with these quick shortcuts." : "Zrýchlite používanie Súborov využitím klávesových skratiek.",
-    "Open the actions menu for a file" : "Otvoriť menu akcií pre súbor",
-    "Rename a file" : "Premenovať súbor",
-    "Delete a file" : "Zmazať súbor",
-    "Favorite or remove a file from favorites" : "Pridať alebo odobrať súbor z obľúbených",
-    "Manage tags for a file" : "Spravovať štítky súborov",
+    "File actions" : "Akcie súboru",
+    "Rename" : "Premenovať",
+    "Delete" : "Zmazať",
+    "Manage tags" : "Spravovať štítky",
     "Selection" : "Výber",
     "Select all files" : "Vybrať všetky súbory",
-    "Deselect all files" : "Zrušiť výber všetkých súborov",
-    "Select or deselect a file" : "Vybrať alebo zrušiť výber súboru",
-    "Select a range of files" : "Vybrať viacero súborov",
+    "Deselect all" : "Odznačiť všetko",
     "Navigation" : "Navigácia",
-    "Navigate to the parent folder" : "Navigovať do nadradeného adresára",
-    "Navigate to the file above" : "Navigovať na predošlý súbor",
-    "Navigate to the file below" : "Navigovať na ďalší súbor",
-    "Navigate to the file on the left (in grid mode)" : "Navigovať na súbor vľavo (v režime zobrazenia v mriežke)",
-    "Navigate to the file on the right (in grid mode)" : "Navigovať na súbor vpravo (v režime zobrazenia v mriežke)",
     "View" : "Zobraziť",
-    "Toggle the grid view" : "Prepnúť na zobrazenie v mriežke",
-    "Open the sidebar for a file" : "Otvoriť bočný panel pre súbor",
+    "Toggle grid view" : "Prepnúť zobrazenie mriežky",
     "Show those shortcuts" : "Zobraziť klávesové skratky",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Povoliť obmedzenie názvov súborov, aby sa zabezpečila synchronizácia súborov so všetkými klientmi. V predvolenom nastavení sú povolené všetky názvy súborov platné pre POSIX (napr. Linux alebo macOS).",
+    "Files compatibility" : "Kompatibilita súborov",
+    "Enforce Windows compatibility" : "Vynútiť kompatibilitu s Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Tým sa zablokujú názvy súborov, ktoré nie sú platné v systémoch Windows, ako napríklad používanie vyhradených názvov alebo špeciálnych znakov. To však nevynúti kompatibilitu rozlišovania malých a veľkých písmen.",
     "You" : "Vy",
     "Shared multiple times with different people" : "Zdieľané viackrát rôznymi ľuďmi",
+    "Unable to change the favorite state of the file" : "Nie je možné zmeniť stav „obľúbené“ súboru",
     "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
     "Owner" : "Vlastník",
     "Remove from favorites" : "Odstrániť z obľúbených",
@@ -244,7 +229,6 @@ OC.L10N.register(
     "File successfully converted" : "Súbor bol úspešne skonvertovaný",
     "Failed to convert file: {message}" : "Nepodarilo sa skonvertovať súbor: {message}",
     "Failed to convert file" : "Konverzia súboru zlyhala",
-    "Deletion cancelled" : "Zmazanie zrušené",
     "Leave this share" : "Opustiť toto zdieľanie.",
     "Leave these shares" : "Opustiť tieto zdieľania.",
     "Disconnect storage" : "Odpojiť úložisko",
@@ -255,39 +239,36 @@ OC.L10N.register(
     "Delete files" : "Zmazať súbory",
     "Delete folder" : "Zmazať priečinok",
     "Delete folders" : "Zmazať priečinky",
-    "Delete" : "Zmazať",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte sa permanentne vymazať {count} položku","Chystáte sa permanentne vymazať {count} položky","Chystáte sa permanentne vymazať {count} položiek","Chystáte sa permanentne vymazať {count} položiek"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte sa vymazať {count} položku","Chystáte sa vymazať {count} položky","Chystáte sa vymazať {count} položiek","Chystáte sa vymazať {count} položiek"],
     "Confirm deletion" : "Potvrdiť vymazanie",
     "Cancel" : "Zrušiť",
+    "Download" : "Stiahnuť",
     "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
+    "Destination is not a folder" : "Cieľ nie je priečinok",
+    "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
     "(copy)" : "(kopírovať)",
     "(copy %n)" : "(kopírovať %n)",
-    "Move cancelled" : "Presun zrušený",
     "A file or folder with that name already exists in this folder" : "Súbor alebo priečinok s týmto názvom už existuje v tomto priečinku",
     "The files are locked" : "Súbory sú uzamknuté.",
     "The file does not exist anymore" : "Súbor už neexistuje",
     "Choose destination" : "Vyberte cieľ",
     "Copy to {target}" : "Kopírovať do {target}",
-    "Copy" : "Kopírovať",
     "Move to {target}" : "Presunúť do {target}",
     "Move" : "Presunúť",
     "Move or copy operation failed" : "Operácia presunu alebo kopírovania zlyhala",
     "Move or copy" : "Presunúť alebo kopírovať",
-    "Cancelled move or copy of \"{filename}\"." : "Zrušené kopírovanie alebo presun \"{filename}\".",
-    "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
     "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
     "Open in Files" : "Otvoriť v súboroch",
+    "Open locally" : "Otvoriť lokálne",
+    "Failed to redirect to client" : "Nepodarilo sa presmerovať na klienta",
     "Open file locally" : "Otvoriť súbor lokálne",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Súbor by sa mal teraz otvoriť v zariadení. Ak sa tak nestane, skontrolujte, či máte nainštalovanú aplikáciu pre počítače.",
     "Retry and close" : "Skúsiť znova a zatvoriť",
     "Open online" : "Otvoriť online",
-    "Failed to redirect to client" : "Nepodarilo sa presmerovať na klienta",
-    "Open locally" : "Otvoriť lokálne",
-    "Rename" : "Premenovať",
-    "Open details" : "Otvoriť detaily",
+    "Details" : "Podrobnosti",
     "View in folder" : "Zobraziť v priečinku",
     "Today" : "Dnes",
     "Last 7 days" : "Posledných 7 dní",
@@ -300,9 +281,8 @@ OC.L10N.register(
     "PDFs" : "PDFká",
     "Folders" : "Priečinky",
     "Audio" : "Zvuk",
-    "Photos and images" : "Fotky a obrázky",
+    "Images" : "Obrázky",
     "Videos" : "Videá",
-    "New folder creation cancelled" : "Vytvorenie adresára bolo zrušené",
     "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
     "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
     "Create templates folder" : "Vytvoriť adresár pre šablóny",
@@ -323,8 +303,10 @@ OC.L10N.register(
     "Files moved successfully" : "Súbory boli úspešne presunuté",
     "Conflicts resolution skipped" : "Riešenie konfliktov bolo preskočené",
     "Upload cancelled" : "Odosielanie bolo zrušené",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
+    "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
     "This operation is forbidden" : "Táto operácia je zakázaná",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Unexpected error: {error}" : "Neočakávaná chyba: {error}",
     "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
@@ -337,10 +319,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Zoznam obľúbených súborov a priečinkov.",
     "No favorites yet" : "Zatiaľ žiadne obľúbené",
     "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
-    "All files" : "Všetky súbory",
     "List of your files and folders." : "Zoznam vašich súborov a priečinkov.",
-    "All folders" : "Všetky adresáre",
-    "Personal files" : "Osobné súbory",
     "List of your files and folders that are not shared." : "Zoznam vašich súborov a priečinkov, ktoré nie sú zdieľané.",
     "No personal files found" : "Žiadne osobné súbory nenájdené",
     "Files that are not shared will show up here." : "Súbory, ktoré nie sú zdieľané, sa tu nezobrazia.",
@@ -348,12 +327,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Zoznam nedávno upravených súborov a priečinkov.",
     "No recently modified files" : "Žiadne nedávno upravené súbory",
     "Files and folders you recently modified will show up here." : "Súbory a priečinky, ktoré ste nedávno upravili sa zobrazia tu",
+    "Search" : "Hľadať",
     "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
     "Select all" : "Vybrať všetko",
     "Upload too large" : "Nahrávanie je príliš veľké",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
     "File could not be found" : "Súbor nie je možné nájsť",
-    "Download" : "Stiahnuť",
     "Show list view" : "Zobraziť ako zoznam",
     "Show grid view" : "Zobraziť v mriežke",
     "Close" : "Zavrieť",
@@ -378,12 +357,12 @@ OC.L10N.register(
     "Edit locally" : "Editovať lokálne",
     "Open" : "Otvoriť",
     "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
-    "Details" : "Podrobnosti",
     "Please select tag(s) to add to the selection" : "Prosím vyberte štítok (štítky) pre pridanie do výberu",
     "Apply tag(s) to selection" : "Aplikovať štítok(štítky) do výberu",
     "Select directory \"{dirName}\"" : "Vybrať priečinok \"{dirName}\"",
     "Select file \"{fileName}\"" : "Vybrať súbor \"{fileName}\"",
     "Unable to determine date" : "Nemožno určiť dátum",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
     "Could not move \"{file}\", target exists" : "Nie je možné presunúť \"{file}\", cieľ už existuje",
     "Could not move \"{file}\"" : "Nie je možné presunúť \"{file}\"",
     "copy" : "kópia",
@@ -392,9 +371,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Skopírované {origin} do {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopírované {origin} a {nbfiles} ostatných súborov do {destination}",
     "{newName} already exists" : "{newName} už existuje",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Nie je možné premenovať \"{fileName}\", cieľ už neexistuje",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{targetName}\" je už použitý v priečinku \"{dir}\". Zvoľte prosím iný názov.",
-    "Could not rename \"{fileName}\"" : "Nie je možné premenovať \"{fileName}\"",
     "Could not create file \"{file}\"" : "Nie je možné vytvoriť súbor \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Nie je možné vytvoriť súbor \"{file}\" lebo už existuje",
     "Could not create folder \"{dir}\" because it already exists" : "Nie je možné vytvoriť priečinok \"{dir}\" lebo už existuje",
@@ -427,35 +403,59 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Priamy odkaz bol skopirovaný (funguje iba pre užívateľov, ktorí majú prístup k danému súboru/adresáru)",
     "Path" : "Cesta",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
-    "Favorited" : "Pridané k obľúbeným",
+    "Favored" : "Zaradiť medzi obľúbené",
+    "Favor" : "Zaradené medzi obľúbené",
     "Copy direct link (only works for people who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre užívateľov, ktorí majú prístup k tomuto súboru/priečinku)",
     "Upload file" : "Nahrať súbor",
-    "Not favorited" : "Nie je obľúbený",
+    "Not favored" : "Nie je v obľúbených",
     "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
-    "You don't have permission to upload or create files here." : "Nemáte oprávnenie nahrávať alebo vytvárať súbory v tomto mieste.",
-    "Storage informations" : "Úložiskové informácie",
-    "Choose file" : "Vybrať súbor",
-    "Go to the previous folder" : "Prejsť do predchádzajúceho priečinka",
-    "Open the files app settings" : "Otvoriť nastavenia súborovej aplikácie",
-    "Unable to change the favourite state of the file" : "Nie je možné zmeniť stav „obľúbené“ daného súboru",
-    "Edit file locally" : "Editovať súbor lokálne",
-    "Edit online" : "Upraviť online",
-    "Create new templates folder" : "Vytvoriť nový vzorový priečinok",
+    "Upload (max. %s)" : "Nahrať (max. %s)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" akcia vykonaná úspešne",
+    "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
+    "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
+    "Submitting fields…" : "Položky sa odosielajú ...",
+    "Filter filenames…" : "Filtrovať názvy súborov...",
+    "WebDAV URL copied to clipboard" : "WebDAV URL skopirovaná do schránky",
+    "Enable the grid view" : "Povoliť zobrazenie v mriežke",
+    "Enable folder tree" : "Povoliť adresárový strom",
+    "Copy to clipboard" : "Skopírovať do schránky",
+    "Use this address to access your Files via WebDAV" : "Táto adresa sa používa na prístup k vašim súborom prostredníctvom WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ak ste povolili 2FA, musíte kliknutím sem vytvoriť a použiť nové heslo pre aplikáciu.",
+    "Deletion cancelled" : "Zmazanie zrušené",
+    "Move cancelled" : "Presun zrušený",
+    "Cancelled move or copy of \"{filename}\"." : "Zrušené kopírovanie alebo presun \"{filename}\".",
+    "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
+    "Open details" : "Otvoriť detaily",
+    "Photos and images" : "Fotky a obrázky",
+    "New folder creation cancelled" : "Vytvorenie adresára bolo zrušené",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} priečinok","{folderCount} priečinky","{folderCount} priečinkov","{folderCount} priečinkov"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} súbor","{fileCount} súbory","{fileCount} súborov","{fileCount} súborov"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 súbor a {folderCount} priečinok","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} súbor a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} súborov a {folderCount} priečinkov",
-    "List of favorites files and folders." : "Zoznam obľúbených súborov a priečinkov.",
+    "All folders" : "Všetky adresáre",
     "Personal Files" : "Osobné Súbory",
     "Text file" : "Textový súbor",
     "New text file.txt" : "Nový text file.txt",
-    "Favored" : "Zaradiť medzi obľúbené",
-    "Favor" : "Zaradené medzi obľúbené",
-    "Not favored" : "Nie je v obľúbených",
-    "Submitting fields…" : "Položky sa odosielajú ...",
-    "Filter filenames…" : "Filtrovať názvy súborov...",
-    "{count} files could not be converted" : "{count} súborov sa nepodarilo skonvertovať",
-    "{count} files successfully converted" : "{count} súborov bolo skonvertovaných"
+    "Filter file names …" : "Filtrovať názvy súborov ...",
+    "Prevent warning dialogs from open or reenable them." : "Zabrániť otváraniu varovných dialógov alebo ich znova povoliť.",
+    "Show a warning dialog when changing a file extension." : "Pri zmene prípony súboru zobraziť dialógové okno s upozornením.",
+    "Speed up your Files experience with these quick shortcuts." : "Zrýchlite používanie Súborov využitím klávesových skratiek.",
+    "Open the actions menu for a file" : "Otvoriť menu akcií pre súbor",
+    "Rename a file" : "Premenovať súbor",
+    "Delete a file" : "Zmazať súbor",
+    "Favorite or remove a file from favorites" : "Pridať alebo odobrať súbor z obľúbených",
+    "Manage tags for a file" : "Spravovať štítky súborov",
+    "Deselect all files" : "Zrušiť výber všetkých súborov",
+    "Select or deselect a file" : "Vybrať alebo zrušiť výber súboru",
+    "Select a range of files" : "Vybrať viacero súborov",
+    "Navigate to the parent folder" : "Navigovať do nadradeného adresára",
+    "Navigate to the file above" : "Navigovať na predošlý súbor",
+    "Navigate to the file below" : "Navigovať na ďalší súbor",
+    "Navigate to the file on the left (in grid mode)" : "Navigovať na súbor vľavo (v režime zobrazenia v mriežke)",
+    "Navigate to the file on the right (in grid mode)" : "Navigovať na súbor vpravo (v režime zobrazenia v mriežke)",
+    "Toggle the grid view" : "Prepnúť na zobrazenie v mriežke",
+    "Open the sidebar for a file" : "Otvoriť bočný panel pre súbor"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
