@@ -94,9 +94,9 @@ OC.L10N.register(
     "Set a password" : "Cunfigura una crae",
     "Password" : "Crae",
     "Generate a new password" : "Gènera una crae noa",
-    "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
+    "Link copied" : "Ligòngiu copiadu",
     "Share link" : "Cumpartzi ligòngiu",
-    "Copy to clipboard" : "Còpia in is punta de billete",
+    "Copy" : "Còpia",
     "Select" : "Seletziona",
     "Close" : "Serra",
     "File request created" : "Rechesta de archìviu creada",
@@ -119,17 +119,13 @@ OC.L10N.register(
     "Via “{folder}”" : "Tràmite “{folder}”",
     "Unshare" : "Annulla sa cumpartzidura",
     "Cannot copy, please copy the link manually" : "No at fatu a copiare, copia su ligòngiu a manu",
-    "Copy internal link to clipboard" : "Còpia su ligòngiu internu in punta de billete",
-    "Only works for people with access to this folder" : "Funtzionat isceti pro gente cun atzessu a custa cartella",
-    "Only works for people with access to this file" : "Funtzionat isceti pro gente cun atzessu a custu archìviu",
-    "Link copied" : "Ligòngiu copiadu",
+    "Copy internal link" : "Còpia ligòngiu internu",
     "Internal link" : "Ligòngiu internu",
     "{shareWith} by {initiator}" : "{shareWith} dae {initiator}",
     "Shared via link by {initiator}" : "Cumpartzidu cun ligòngiu dae {initiator}",
     "Mail share ({label})" : "Cumpartzidura cun posta eletrònica ({label})",
     "Share link ({label})" : "Cumpartzi ligòngiu ({label})",
     "Create public link" : "Crea unu ligòngiu pùblicu",
-    "Copy public link of \"{title}\" to clipboard" : "Còpia in punta de billete su ligòngiu pùblicu pro: \"{title}\"",
     "Error, please enter proper password and/or expiration date" : "Errore, inserta una crae giusta e/o sa data de iscadèntzia",
     "Please enter the following required information before creating the share" : "Inserta is informatziones rechertas in fatu in antis de creare sa cumpartzidura",
     "Password protection (enforced)" : "Bardiadura cun crae (posta)",
@@ -148,7 +144,6 @@ OC.L10N.register(
     "Name, email, or Federated Cloud ID …" : "Nùmene, indiritzu de posta o ID de sa nue federada ...",
     "Searching …" : "Chirchende …",
     "No elements found." : "Perunu elementu agatadu.",
-    "Search globally" : "Chirca globale",
     "Guest" : "Persone invitada",
     "Group" : "Grupu",
     "Email" : "Posta eletrònica",
@@ -156,8 +151,6 @@ OC.L10N.register(
     "Deck board" : "Tabella in Deck",
     "on {server}" : "in {server}",
     "Terms of service" : "Cunditziones de servìtziu",
-    "Name" : "Nùmene",
-    "Enter your name" : "Inserta•nche su nùmene tuo",
     "Update share" : "Agiorna sa cumpartzidura",
     "Read" : "Leghe",
     "Create" : "Crea",
@@ -210,21 +203,10 @@ OC.L10N.register(
     "Error updating the share: {errorMessage}" : "Errore in s'agiornamentu de sa cumpartzidura: {errorMessage}",
     "Error updating the share" : "Errore in s'agiornamentu de sa cumpatzidura",
     "Could not update share" : "No at fatu a agiornare sa cumpartzidura",
-    "Shared by" : "Cumpartzidu dae",
-    "Shared with" : "Cumpartzidu cun",
     "Shared with you and the group {group} by {owner}" : "Cumpartzidu cun tegus e su grupu {group} dae {owner}",
     "Shared with you and {circle} by {owner}" : "Cumpartzidu cun tegus {circle} dae {owner}",
     "Shared with you and the conversation {conversation} by {owner}" : "Cumpartzidu cun tegus e sa resonada {conversation} dae {owner}",
     "Shared with you in a conversation by {owner}" : "Cumpartzidu cun tegus in una resonada dae {owner}",
-    "Share note" : "Cumpartzi sa nota",
-    "Show list view" : "Mustra sa visualizatzione de lista",
-    "Show grid view" : "Mustra sa visualizatzione de mosàicu",
-    "Upload files to %s" : "Càrriga archìvios in %s",
-    "Note" : "Nota",
-    "Select or drop files" : "Sèbera o iscapa archìvios",
-    "Uploading files" : "Carrighende archìvios",
-    "Uploaded files:" : "Archìvios carrigados:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "Carrighende is archìvios, cuncordas cun is %1$scunditziones de servìtziu%2$s.",
     "Share not found" : "Cumpartzidura no agatada",
     "Back to %s" : "Torra a %s",
     "Add to your Nextcloud" : "Agiunghe a su Nextcloud tuo",
@@ -234,12 +216,31 @@ OC.L10N.register(
     "This will stop your current uploads." : "Custu at a firmare is carrigamentos tuos atuales.",
     "Move or copy" : "Tràmuda o còpia",
     "You can upload into this folder" : "Podes carrigare in custa cartella",
+    "Show list view" : "Mustra sa visualizatzione de lista",
+    "Show grid view" : "Mustra sa visualizatzione de mosàicu",
     "No compatible server found at {remote}" : "Perunu serbidore cumpatìbile agatadu in {remote}",
     "Invalid server URL" : "URL de su serbidore non vàlidu",
     "Failed to add the public link to your Nextcloud" : "No at fatu a agiùnghere su ligòngiu pùblicu in Nextcloud",
-    "Files" : "Archìvios",
     "Download all files" : "Iscàrriga totu is archìvios",
+    "Link copied to clipboard" : "Ligòngiu copiadu in punta de billete",
+    "Copy to clipboard" : "Còpia in is punta de billete",
+    "Copy internal link to clipboard" : "Còpia su ligòngiu internu in punta de billete",
+    "Only works for people with access to this folder" : "Funtzionat isceti pro gente cun atzessu a custa cartella",
+    "Only works for people with access to this file" : "Funtzionat isceti pro gente cun atzessu a custu archìviu",
+    "Copy public link of \"{title}\" to clipboard" : "Còpia in punta de billete su ligòngiu pùblicu pro: \"{title}\"",
+    "Search globally" : "Chirca globale",
     "Search for share recipients" : "Chirca destinatàrios de cumpartziduras",
-    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere."
+    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere.",
+    "Enter your name" : "Inserta•nche su nùmene tuo",
+    "Shared by" : "Cumpartzidu dae",
+    "Shared with" : "Cumpartzidu cun",
+    "Share note" : "Cumpartzi sa nota",
+    "Upload files to %s" : "Càrriga archìvios in %s",
+    "Note" : "Nota",
+    "Select or drop files" : "Sèbera o iscapa archìvios",
+    "Uploading files" : "Carrighende archìvios",
+    "Uploaded files:" : "Archìvios carrigados:",
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "Carrighende is archìvios, cuncordas cun is %1$scunditziones de servìtziu%2$s.",
+    "Name" : "Nùmene"
 },
 "nplurals=2; plural=(n != 1);");
